@@ -25,11 +25,19 @@ them (as in `Activity.from_provenance()`)
 import uuid
 import warnings
 from collections import OrderedDict
+import os
+import pwd
 
-from traitlets import Enum, Unicode, Int, HasTraits, default, Instance
+import tables
+from astropy.time import Time
+from tables import NaturalNameWarning
+from traitlets import Enum, Instance, List, Unicode, default, HasTraits
+from traitlets.config import Configurable
+from contextlib import ExitStack
+from pathlib import Path
 
-from ctapipe.core.provenance import _ActivityProvenance
-from ctapipe.core.traits import AstroTime
+from ..core.traits import AstroTime
+from .datalevels import DataLevel
 
 __all__ = [
     "Reference",
@@ -39,20 +47,30 @@ __all__ = [
     "Activity",
     "Instrument",
     "write_to_hdf5",
+    "read_metadata",
 ]
 
-from astropy.time import Time
+
+CONVERSIONS = {Time: lambda t: t.utc.iso, list: str}
 
 
-CONVERSIONS = {Time: lambda t: t.utc.iso}
-
-
-class Contact(HasTraits):
+class Contact(Configurable):
     """ Contact information """
 
-    name = Unicode("unknown")
-    email = Unicode("unknown")
-    organization = Unicode("unknown")
+    name = Unicode("unknown").tag(config=True)
+    email = Unicode("unknown").tag(config=True)
+    organization = Unicode("unknown").tag(config=True)
+
+    @default("name")
+    def default_name(self):
+        """ if no name specified, use the system's user name"""
+        try:
+            return pwd.getpwuid(os.getuid()).pw_gecos
+        except RuntimeError:
+            return ""
+
+    def __repr__(self):
+        return f"Contact(name={self.name}, email={self.email}, organization={self.organization})"
 
 
 class Product(HasTraits):
@@ -61,10 +79,8 @@ class Product(HasTraits):
     description = Unicode("unknown")
     creation_time = AstroTime()
     id_ = Unicode(help="leave unspecified to automatically generate a UUID")
-    data_category = Enum(["S", "A", "B", "C", "Other"], "Other")
-    data_level = Enum(
-        ["R0", "R1", "DL0", "DL1", "DL2", "DL3", "DL4", "DL5", "DL6", "Other"], "Other"
-    )
+    data_category = Enum(["Sim", "A", "B", "C", "Other"], "Other")
+    data_level = List(Enum([level.name for level in DataLevel]))
     data_association = Enum(["Subarray", "Telescope", "Target", "Other"], "Other")
     data_model_name = Unicode("unknown")
     data_model_version = Unicode("unknown")
@@ -88,7 +104,7 @@ class Process(HasTraits):
 
     type_ = Enum(["Observation", "Simulation", "Other"], "Other")
     subtype = Unicode("")
-    id_ = Int()
+    id_ = Unicode("")
 
 
 class Activity(HasTraits):
@@ -167,9 +183,13 @@ def _to_dict(hastraits_instance, prefix=""):
     """
     res = {}
 
-    for k, tr in hastraits_instance.traits().items():
+    ignore = {"parent", "config"}
+    for k, trait in hastraits_instance.traits().items():
+        if k in ignore:
+            continue
+
         key = (prefix + k.upper().replace("_", " ")).replace("  ", " ").strip()
-        val = tr.get(hastraits_instance)
+        val = trait.get(hastraits_instance)
 
         # apply type conversions
         val = CONVERSIONS.get(type(val), lambda v: v)(val)
@@ -205,7 +225,7 @@ class Reference(HasTraits):
         return meta
 
 
-def write_to_hdf5(metadata, h5file):
+def write_to_hdf5(metadata, h5file, path='/'):
     """
     Write metadata fields to a PyTables HDF5 file handle.
 
@@ -213,12 +233,45 @@ def write_to_hdf5(metadata, h5file):
     ----------
     metadata: dict
         flat dict as generated by `Reference.to_dict()`
-    h5file: tables.file.File
+    h5file: string, Path, or `tables.file.File`
         pytables filehandle
+    path: string
+        default: '/' is the path to ctapipe global metadata
+        the node must already exist in the 5hfile
     """
-    from tables import NaturalNameWarning
-
     with warnings.catch_warnings():
         warnings.simplefilter("ignore", NaturalNameWarning)
+        node = h5file.get_node(path)
         for key, value in metadata.items():
-            h5file.root._v_attrs[key] = value  # pylint: disable=protected-access
+            node._v_attrs[key] = value  # pylint: disable=protected-access
+
+
+def read_metadata(h5file, path='/'):
+    """
+    Read metadata from an hdf5 file
+
+    Parameters
+    ----------
+    h5filename: string, Path, or `tables.file.File`
+        hdf5 file
+    path: string
+        default: '/' is the path to ctapipe global metadata
+
+    Returns
+    -------
+    metadata: dictionnary
+    """
+    with ExitStack() as stack:
+        if isinstance(h5file, (str, Path)):
+            h5file = stack.enter_context(tables.open_file(h5file))
+        elif isinstance(h5file, tables.file.File):
+            pass
+        else:
+            raise ValueError(
+                f"expected a string, Path, or PyTables "
+                f"filehandle for argument 'h5file', got {h5file}"
+            )
+
+        node = h5file.get_node(path)
+        metadata = {key: node._v_attrs[key] for key in node._v_attrs._f_list()}
+    return metadata
