@@ -22,7 +22,13 @@ from ..containers import (
     TelescopeTriggerContainer,
 )
 from ..coordinates import CameraFrame
-from ..core.traits import Bool, CaselessStrEnum, create_class_enum_trait
+from ..core.traits import (
+    Bool,
+    Float,
+    CaselessStrEnum,
+    create_class_enum_trait,
+    Undefined,
+)
 from ..instrument import (
     CameraDescription,
     CameraGeometry,
@@ -32,11 +38,11 @@ from ..instrument import (
     TelescopeDescription,
 )
 from ..instrument.camera import UnknownPixelShapeWarning
-from ..instrument.guess import UNKNOWN_TELESCOPE, guess_telescope
+from ..instrument.guess import unknown_telescope, guess_telescope
 from .datalevels import DataLevel
 from .eventsource import EventSource
 
-X_MAX_UNIT = u.g / (u.cm ** 2)
+X_MAX_UNIT = u.g / (u.cm**2)
 
 
 __all__ = ["SimTelEventSource"]
@@ -79,7 +85,7 @@ def build_camera(cam_settings, pixel_settings, telescope, frame):
         pix_id=np.arange(cam_settings["n_pixels"]),
         pix_x=u.Quantity(cam_settings["pixel_x"], u.m),
         pix_y=u.Quantity(cam_settings["pixel_y"], u.m),
-        pix_area=u.Quantity(cam_settings["pixel_area"], u.m ** 2),
+        pix_area=u.Quantity(cam_settings["pixel_area"], u.m**2),
         pix_type=pix_type,
         pix_rotation=pix_rotation,
         cam_rotation=-Angle(cam_settings["cam_rot"], u.rad),
@@ -100,7 +106,9 @@ def build_camera(cam_settings, pixel_settings, telescope, frame):
     )
 
 
-def apply_simtel_r1_calibration(r0_waveforms, pedestal, dc_to_pe, gain_selector):
+def apply_simtel_r1_calibration(
+    r0_waveforms, pedestal, dc_to_pe, gain_selector, calib_scale=1.0, calib_shift=0.0
+):
     """
     Perform the R1 calibration for R0 simtel waveforms. This includes:
         - Gain selection
@@ -123,6 +131,14 @@ def apply_simtel_r1_calibration(r0_waveforms, pedestal, dc_to_pe, gain_selector)
         simtel file for each gain channel
         Shape: (n_channels, n_pixels)
     gain_selector : ctapipe.calib.camera.gainselection.GainSelector
+    calib_scale : float
+        Extra global scale factor for calibration.
+        Conversion factor to transform the integrated charges
+        (in ADC counts) into number of photoelectrons on top of dc_to_pe.
+        Defaults to no scaling.
+    calib_shift: float
+        Shift the resulting R1 output in p.e. for simulating miscalibration.
+        Defaults to no shift.
 
     Returns
     -------
@@ -135,8 +151,9 @@ def apply_simtel_r1_calibration(r0_waveforms, pedestal, dc_to_pe, gain_selector)
     """
     n_channels, n_pixels, n_samples = r0_waveforms.shape
     ped = pedestal[..., np.newaxis]
-    gain = dc_to_pe[..., np.newaxis]
-    r1_waveforms = (r0_waveforms - ped) * gain
+    DC_to_PHE = dc_to_pe[..., np.newaxis]
+    gain = DC_to_PHE * calib_scale
+    r1_waveforms = (r0_waveforms - ped) * gain + calib_shift
     if n_channels == 1:
         selected_gain_channel = np.zeros(n_pixels, dtype=np.int8)
         r1_waveforms = r1_waveforms[0]
@@ -147,7 +164,7 @@ def apply_simtel_r1_calibration(r0_waveforms, pedestal, dc_to_pe, gain_selector)
 
 
 class SimTelEventSource(EventSource):
-    """ Read events from a SimTelArray data file (in EventIO format)."""
+    """Read events from a SimTelArray data file (in EventIO format)."""
 
     skip_calibration_events = Bool(True, help="Skip calibration events").tag(
         config=True
@@ -178,7 +195,23 @@ class SimTelEventSource(EventSource):
         base_class=GainSelector, default_value="ThresholdGainSelector"
     ).tag(config=True)
 
-    def __init__(self, input_url=None, config=None, parent=None, **kwargs):
+    calib_scale = Float(
+        default_value=1.0,
+        help=(
+            "Factor to transform ADC counts into number of photoelectrons."
+            " Corrects the DC_to_PHE factor."
+        ),
+    ).tag(config=True)
+
+    calib_shift = Float(
+        default_value=0.0,
+        help=(
+            "Factor to shift the R1 photoelectron samples. "
+            "Can be used to simulate mis-calibration."
+        ),
+    ).tag(config=True)
+
+    def __init__(self, input_url=Undefined, config=None, parent=None, **kwargs):
         """
         EventSource for simtelarray files using the pyeventio library.
 
@@ -198,8 +231,6 @@ class SimTelEventSource(EventSource):
         """
         super().__init__(input_url=input_url, config=config, parent=parent, **kwargs)
 
-        self._camera_cache = {}
-
         self.file_ = SimTelFile(
             self.input_url.expanduser(),
             allowed_telescopes=self.allowed_tels,
@@ -268,12 +299,15 @@ class SimTelEventSource(EventSource):
         tel_descriptions = {}  # tel_id : TelescopeDescription
         tel_positions = {}  # tel_id : TelescopeDescription
 
+        self.telescope_indices_original = {}
+
         for tel_id, telescope_description in telescope_descriptions.items():
             cam_settings = telescope_description["camera_settings"]
             pixel_settings = telescope_description["pixel_settings"]
 
             n_pixels = cam_settings["n_pixels"]
             focal_length = u.Quantity(cam_settings["focal_length"], u.m)
+            mirror_area = u.Quantity(cam_settings["mirror_area"], u.m**2)
 
             if self.focal_length_choice == "effective":
                 try:
@@ -290,25 +324,22 @@ class SimTelEventSource(EventSource):
             try:
                 telescope = guess_telescope(n_pixels, focal_length)
             except ValueError:
-                telescope = UNKNOWN_TELESCOPE
+                telescope = unknown_telescope(mirror_area, n_pixels)
 
             optics = OpticsDescription(
                 name=telescope.name,
                 num_mirrors=telescope.n_mirrors,
                 equivalent_focal_length=focal_length,
-                mirror_area=u.Quantity(cam_settings["mirror_area"], u.m ** 2),
+                mirror_area=mirror_area,
                 num_mirror_tiles=cam_settings["n_mirrors"],
             )
 
-            camera = self._camera_cache.get(telescope.camera_name)
-            if camera is None:
-                camera = build_camera(
-                    cam_settings,
-                    pixel_settings,
-                    telescope,
-                    frame=CameraFrame(focal_length=optics.equivalent_focal_length),
-                )
-                self._camera_cache[telescope.camera_name] = camera
+            camera = build_camera(
+                cam_settings,
+                pixel_settings,
+                telescope,
+                frame=CameraFrame(focal_length=optics.equivalent_focal_length),
+            )
 
             tel_descriptions[tel_id] = TelescopeDescription(
                 name=telescope.name,
@@ -318,6 +349,7 @@ class SimTelEventSource(EventSource):
             )
 
             tel_idx = np.where(header["tel_id"] == tel_id)[0][0]
+            self.telescope_indices_original[tel_id] = tel_idx
             tel_positions[tel_id] = header["tel_pos"][tel_idx] * u.m
 
         subarray = SubarrayDescription(
@@ -326,8 +358,11 @@ class SimTelEventSource(EventSource):
             tel_descriptions=tel_descriptions,
         )
 
+        self.n_telescopes_original = len(subarray)
+
         if self.allowed_tels:
             subarray = subarray.select_subarray(self.allowed_tels)
+
         return subarray
 
     @staticmethod
@@ -362,18 +397,6 @@ class SimTelEventSource(EventSource):
         self._fill_array_pointing(data)
 
         for counter, array_event in enumerate(self.file_):
-
-            event_id = array_event.get("event_id", -1)
-            obs_id = self.file_.header["run"]
-            data.count = counter
-            data.index.obs_id = obs_id
-            data.index.event_id = event_id
-
-            self._fill_trigger_info(data, array_event)
-
-            if data.trigger.event_type == EventType.SUBARRAY:
-                self._fill_simulated_event_information(data, array_event)
-
             # this should be done in a nicer way to not re-allocate the
             # data each time (right now it's just deleted and garbage
             # collected)
@@ -383,10 +406,25 @@ class SimTelEventSource(EventSource):
             data.dl1.tel.clear()
             data.pointing.tel.clear()
             data.simulation.tel.clear()
+            data.trigger.tel.clear()
+
+            event_id = array_event.get("event_id", -1)
+            obs_id = self.file_.header["run"]
+            data.count = counter
+            data.index.obs_id = obs_id
+            data.index.event_id = event_id
+
+            self._fill_trigger_info(data, array_event)
+            if data.trigger.event_type == EventType.SUBARRAY:
+                self._fill_simulated_event_information(data, array_event)
 
             telescope_events = array_event["telescope_events"]
             tracking_positions = array_event["tracking_positions"]
 
+            true_image_sums = array_event.get("photoelectron_sums", {}).get(
+                "n_pe", np.full(self.n_telescopes_original, np.nan)
+            )
+
             for tel_id, telescope_event in telescope_events.items():
                 adc_samples = telescope_event.get("adc_samples")
                 if adc_samples is None:
@@ -400,7 +438,10 @@ class SimTelEventSource(EventSource):
                 )
 
                 data.simulation.tel[tel_id] = SimulatedCameraContainer(
-                    true_image=true_image
+                    true_image_sum=true_image_sums[
+                        self.telescope_indices_original[tel_id]
+                    ],
+                    true_image=true_image,
                 )
 
                 data.pointing.tel[tel_id] = self._fill_event_pointing(
@@ -422,7 +463,12 @@ class SimTelEventSource(EventSource):
                 mon.calibration.pedestal_per_sample = pedestal
 
                 r1.waveform, r1.selected_gain_channel = apply_simtel_r1_calibration(
-                    adc_samples, pedestal, dc_to_pe, self.gain_selector
+                    adc_samples,
+                    pedestal,
+                    dc_to_pe,
+                    self.gain_selector,
+                    self.calib_scale,
+                    self.calib_shift,
                 )
 
                 # get time_shift from laser calibration
@@ -522,9 +568,19 @@ class SimTelEventSource(EventSource):
             data.pointing.array_dec = u.Quantity(dec, u.rad)
 
     def _parse_simulation_header(self):
+        """
+        Parse the simulation infos and return a dict with
+        observation ids mapped to SimulationConfigContainers.
+        As merged simtel files are not supported at this
+        point in time, this dictionary will always have
+        length 1.
+        """
+        assert len(self.obs_ids) == 1
+        obs_id = self.obs_ids[0]
+        # With only one run, we can take the first entry:
         mc_run_head = self.file_.mc_run_headers[-1]
 
-        return SimulationConfigContainer(
+        simulation_config = SimulationConfigContainer(
             corsika_version=mc_run_head["shower_prog_vers"],
             simtel_version=mc_run_head["detector_prog_vers"],
             energy_range_min=mc_run_head["E_range"][0] * u.TeV,
@@ -561,6 +617,7 @@ class SimTelEventSource(EventSource):
             corsika_low_E_detail=mc_run_head["corsika_low_E_detail"],
             corsika_high_E_detail=mc_run_head["corsika_high_E_detail"],
         )
+        return {obs_id: simulation_config}
 
     @staticmethod
     def _fill_simulated_event_information(data, array_event):
