@@ -1,20 +1,39 @@
 #!/usr/bin/env python3
+import warnings
 import numpy as np
 from astropy import units as u
 import tables
 import pytest
 from astropy.time import Time
+from astropy.table import Table
+from astropy.utils.diff import report_diff_values
+
+from astropy.io.fits.verify import VerifyWarning
 
 from ctapipe.core import Container, Field
 from ctapipe.containers import ReconstructedEnergyContainer, TelescopeTriggerContainer
 from ctapipe.io import HDF5TableWriter
 from ctapipe.io.astropy_helpers import read_table
+from io import StringIO
+
+
+
+def assert_table_equal(a, b):
+    '''
+    Assert that two astropy tables are the same.
+
+    Compares two tables using the astropy diff utility
+    and use the report as error message in case they don't match
+    '''
+    msg = StringIO()
+    msg.write('\n')
+    valid = report_diff_values(a, b, fileobj=msg)
+    msg.seek(0)
+    assert valid, msg.read()
 
 
 def test_read_table(tmp_path):
-
     # write a simple hdf5 file using
-
     container = ReconstructedEnergyContainer()
     filename = tmp_path / "test_astropy_table.h5"
 
@@ -36,14 +55,17 @@ def test_read_table(tmp_path):
 
     # test write the table back out to some other format:
     table.write(tmp_path / "test_output.ecsv")
-    table.write(tmp_path / "test_output.fits.gz")
+    with warnings.catch_warnings():
+        # ignore warnings about too long keywords stored using HIERARCH
+        warnings.simplefilter("ignore", VerifyWarning)
+        table.write(tmp_path / "test_output.fits.gz")
 
     # test using a file handle
     with tables.open_file(filename) as handle:
         table = read_table(handle, "/events")
 
     # test a bad input
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         table = read_table(12345, "/events")
 
 
@@ -107,7 +129,6 @@ def test_transforms(tmp_path):
     path = tmp_path / "test_trans.hdf5"
 
     data = np.array([100, 110], dtype="int16").view([("waveform", "int16")])
-    print(data)
 
     with tables.open_file(path, "w") as f:
         f.create_table("/data", "test", obj=data, createparents=True)
@@ -134,3 +155,36 @@ def test_file_closed(tmp_path):
     # the file
     with tables.open_file(path, "w"):
         pass
+
+
+def test_condition(tmp_path):
+    # write a simple hdf5 file using
+
+    container = ReconstructedEnergyContainer()
+    filename = tmp_path / "test_astropy_table.h5"
+
+    with HDF5TableWriter(filename) as writer:
+        for energy in [np.nan, 100, np.nan, 50, -1.0] * u.TeV:
+            container.energy = energy
+            writer.write("events", container)
+
+    # try opening the result
+    table = read_table(filename, "/events", condition="energy > 0")
+    assert len(table) == 2
+    assert np.all(table["energy"] == [100, 50] * u.TeV)
+
+
+def test_read_table_astropy(tmp_path):
+    """Test that ctapipe.io.read_table can also read a table written Table.write"""
+    table = Table(
+        {
+            "a": [1, 2, 3],
+            "b": np.array([1, 2, 3], dtype=np.uint16),
+            "speed": [2.0, 3.0, 4.2] * (u.m / u.s),
+        }
+    )
+
+    path = tmp_path / "test.h5"
+    table.write(path, "/group/table", serialize_meta=True)
+    read = read_table(path, "/group/table")
+    assert_table_equal(table, read)
