@@ -44,23 +44,6 @@ def test_simtel_event_source_on_gamma_test_one_event():
                 assert event.count == 0
                 break
 
-    # test that max_events works:
-    max_events = 5
-    with SimTelEventSource(
-        input_url=gamma_test_large_path, max_events=max_events
-    ) as reader:
-        count = 0
-        for _ in reader:
-            count += 1
-        assert count == max_events
-
-    # test that the allowed_tels mask works:
-    with SimTelEventSource(
-        input_url=gamma_test_large_path, allowed_tels={3, 4}
-    ) as reader:
-        for event in reader:
-            assert set(event.r0.tel).issubset(reader.allowed_tels)
-
 
 def test_that_event_is_not_modified_after_loop():
 
@@ -79,18 +62,22 @@ def test_that_event_is_not_modified_after_loop():
 
 def test_additional_meta_data_from_simulation_config():
     with SimTelEventSource(input_url=gamma_test_large_path) as reader:
-        data = next(iter(reader))
+        next(iter(reader))
 
     # for expectation values
     from astropy import units as u
     from astropy.coordinates import Angle
 
-    assert reader.simulation_config.corsika_version == 6990
-    assert reader.simulation_config.spectral_index == -2.0
-    assert reader.simulation_config.shower_reuse == 20
-    assert reader.simulation_config.core_pos_mode == 1
-    assert reader.simulation_config.diffuse == 1
-    assert reader.simulation_config.atmosphere == 26
+    # There should be only one observation
+    assert len(reader.obs_ids) == 1
+    simulation_config = reader.simulation_config[reader.obs_ids[0]]
+
+    assert simulation_config.corsika_version == 6990
+    assert simulation_config.spectral_index == -2.0
+    assert simulation_config.shower_reuse == 20
+    assert simulation_config.core_pos_mode == 1
+    assert simulation_config.diffuse == 1
+    assert simulation_config.atmosphere == 26
 
     # value read by hand from input card
     name_expectation = {
@@ -108,7 +95,7 @@ def test_additional_meta_data_from_simulation_config():
     }
 
     for name, expectation in name_expectation.items():
-        value = getattr(reader.simulation_config, name)
+        value = getattr(simulation_config, name)
 
         assert value.unit == expectation.unit
         assert np.isclose(
@@ -120,9 +107,9 @@ def test_properties():
     source = SimTelEventSource(input_url=gamma_test_large_path)
 
     assert source.is_simulation
-    assert source.simulation_config.corsika_version == 6990
     assert source.datalevels == (DataLevel.R0, DataLevel.R1)
     assert source.obs_ids == [7514]
+    assert source.simulation_config[7514].corsika_version == 6990
 
 
 def test_gamma_file():
@@ -173,7 +160,7 @@ def test_allowed_telescopes():
     # test that the allowed_tels mask works:
     allowed_tels = {3, 4}
     with SimTelEventSource(
-        input_url=gamma_test_large_path, allowed_tels=allowed_tels
+        input_url=gamma_test_large_path, allowed_tels=allowed_tels, max_events=5
     ) as reader:
         assert not allowed_tels.symmetric_difference(reader.subarray.tel_ids)
         for event in reader:
@@ -229,13 +216,6 @@ def test_true_image():
                 assert np.count_nonzero(tel.true_image) > 0
 
 
-def test_camera_caching():
-    """Test if same telescope types share a single instance of CameraGeometry"""
-    source = SimTelEventSource(input_url=gamma_test_large_path)
-    subarray = source.subarray
-    assert subarray.tel[1].camera is subarray.tel[2].camera
-
-
 def test_instrument():
     """Test if same telescope types share a single instance of CameraGeometry"""
     source = SimTelEventSource(input_url=gamma_test_large_path)
@@ -331,3 +311,68 @@ def test_only_config():
 
     s = SimTelEventSource(config=config)
     assert s.input_url == Path(gamma_test_large_path).absolute()
+
+
+def test_calibscale_and_calibshift(prod5_gamma_simtel_path):
+
+    telid = 25
+
+    with SimTelEventSource(input_url=prod5_gamma_simtel_path, max_events=1) as source:
+
+        for event in source:
+            pass
+
+    calib_scale = 2.0
+
+    with SimTelEventSource(
+        input_url=prod5_gamma_simtel_path, max_events=1, calib_scale=calib_scale
+    ) as source:
+
+        for event_scaled in source:
+            pass
+
+    np.testing.assert_allclose(
+        event.r1.tel[telid].waveform[0],
+        event_scaled.r1.tel[telid].waveform[0] / calib_scale,
+        rtol=0.1,
+    )
+
+    calib_shift = 2.0  # p.e.
+
+    with SimTelEventSource(
+        input_url=prod5_gamma_simtel_path, max_events=1, calib_shift=calib_shift
+    ) as source:
+
+        for event_shifted in source:
+            pass
+
+    np.testing.assert_allclose(
+        event.r1.tel[telid].waveform[0],
+        event_shifted.r1.tel[telid].waveform[0] - calib_shift,
+        rtol=0.1,
+    )
+
+
+def test_true_image_sum():
+    # this file does not contain true pe info
+    with SimTelEventSource(gamma_test_large_path) as s:
+        e = next(iter(s))
+        assert np.all(np.isnan(sim.true_image_sum) for sim in e.simulation.tel.values())
+
+    with SimTelEventSource(calib_events_path) as s:
+        e = next(iter(s))
+
+        true_image_sums = {}
+        for tel_id, sim_camera in e.simulation.tel.items():
+            # since the test file contains both sums and individual pixel values
+            # we can compare.
+            assert sim_camera.true_image_sum == sim_camera.true_image.sum()
+            true_image_sums[tel_id] = sim_camera.true_image_sum
+
+    # check it also works with allowed_tels, since the values
+    # are stored in a flat array in simtel
+    with SimTelEventSource(calib_events_path, allowed_tels={2, 3}) as s:
+        e = next(iter(s))
+
+        assert e.simulation.tel[2].true_image_sum == true_image_sums[2]
+        assert e.simulation.tel[3].true_image_sum == true_image_sums[3]
