@@ -23,7 +23,7 @@ from ctapipe.containers import (
 )
 from ctapipe.instrument import get_atmosphere_profile_functions
 
-from astropy.coordinates import SkyCoord
+from astropy.coordinates import SkyCoord, AltAz
 from ctapipe.coordinates import (
     NominalFrame,
     CameraFrame,
@@ -39,6 +39,9 @@ from ctapipe.core import traits
 __all__ = ["HillasIntersection"]
 
 
+INVALID = ReconstructedGeometryContainer(tel_ids=[])
+
+
 class HillasIntersection(Reconstructor):
     """
     This class is a simple re-implementation of Hillas parameter based event
@@ -69,11 +72,11 @@ class HillasIntersection(Reconstructor):
         ["Konrad", "hess"], default_value="Konrad", help="Weighting Method name"
     ).tag(config=True)
 
-    def __init__(self, config=None, parent=None, **kwargs):
+    def __init__(self, subarray, **kwargs):
         """
         Weighting must be a function similar to the weight_konrad already implemented
         """
-        super().__init__(config=config, parent=parent, **kwargs)
+        super().__init__(subarray, **kwargs)
 
         # We need a conversion function from height above ground to depth of maximum
         # To do this we need the conversion table from CORSIKA
@@ -84,7 +87,39 @@ class HillasIntersection(Reconstructor):
         if self.weighting == "Konrad":
             self._weight_method = self.weight_konrad
 
-    def predict(self, hillas_dict, subarray, array_pointing, telescopes_pointings=None):
+
+    def __call__(self, event):
+        '''
+        Perform stereo reconstruction on event.
+
+        Parameters
+        ----------
+        event: `ctapipe.containers.ArrayEventContainer`
+            The event, needs to have dl1 parameters
+
+        Returns
+        -------
+        ReconstructedGeometryContainer
+        '''
+        
+        try:
+            hillas_dict = self._create_hillas_dict(event)
+        except (TooFewTelescopesException, InvalidWidthException):
+            return INVALID
+
+        # Due to tracking the pointing of the array will never be a constant
+        array_pointing = SkyCoord(
+            az=event.pointing.array_azimuth,
+            alt=event.pointing.array_altitude,
+            frame=AltAz(),
+        )
+
+        telescope_pointings = self._get_telescope_pointings(event)
+
+        return self._predict(hillas_dict, array_pointing, telescope_pointings)
+
+
+    def _predict(self, hillas_dict, array_pointing, telescopes_pointings=None):
         """
 
         Parameters
@@ -115,12 +150,12 @@ class HillasIntersection(Reconstructor):
             )
 
         # check for np.nan or 0 width's as these screw up weights
-        if any([np.isnan(hillas_dict[tel]["width"].value) for tel in hillas_dict]):
+        if any([np.isnan(h.width.value) for h in hillas_dict.values()]):
             raise InvalidWidthException(
                 "A HillasContainer contains an ellipse of width==np.nan"
             )
 
-        if any([hillas_dict[tel]["width"].value == 0 for tel in hillas_dict]):
+        if any([h.width.value == 0 for h in hillas_dict.values()]):
             raise InvalidWidthException(
                 "A HillasContainer contains an ellipse of width==0"
             )
@@ -131,11 +166,11 @@ class HillasIntersection(Reconstructor):
             }
 
         tilted_frame = TiltedGroundFrame(pointing_direction=array_pointing)
-        grd_coord = subarray.tel_coords
+        grd_coord = self.subarray.tel_coords
         tilt_coord = grd_coord.transform_to(tilted_frame)
 
         tel_ids = list(hillas_dict.keys())
-        tel_indices = subarray.tel_ids_to_indices(tel_ids)
+        tel_indices = self.subarray.tel_ids_to_indices(tel_ids)
 
         tel_x = {
             tel_id: tilt_coord.x[tel_index]
@@ -152,7 +187,7 @@ class HillasIntersection(Reconstructor):
 
         for tel_id, hillas in hillas_dict.items():
             if isinstance(hillas, CameraHillasParametersContainer):
-                focal_length = subarray.tel[tel_id].optics.equivalent_focal_length
+                focal_length = self.subarray.tel[tel_id].optics.equivalent_focal_length
                 camera_frame = CameraFrame(
                     telescope_pointing=telescopes_pointings[tel_id],
                     focal_length=focal_length,
