@@ -3,24 +3,15 @@ import astropy.units as u
 from numpy.testing import assert_allclose
 import numpy as np
 from astropy.coordinates import SkyCoord
-from ctapipe.coordinates import NominalFrame, AltAz, CameraFrame, TelescopeFrame
+from ctapipe.coordinates import NominalFrame, AltAz, CameraFrame
 from ctapipe.containers import HillasParametersContainer
 
-from ctapipe.io import EventSource
-
-from ctapipe.utils import get_dataset_path
-
-from ctapipe.image.cleaning import tailcuts_clean
-from ctapipe.image.hillas import hillas_parameters, HillasParameterizationError
-from ctapipe.calib import CameraCalibrator
-
 
 def test_intersect():
     """
     Simple test to check the intersection of lines. Try to intersect positions at (0,1) and (1,0)
     with angles perpendicular and test they cross at (0,0)
     """
-    hill = HillasIntersection()
     x1 = 0
     y1 = 1
     theta1 = 90 * u.deg
@@ -29,7 +20,7 @@ def test_intersect():
     y2 = 0
     theta2 = 0 * u.deg
 
-    sx, sy = hill.intersect_lines(x1, y1, theta1, x2, y2, theta2)
+    sx, sy = HillasIntersection.intersect_lines(x1, y1, theta1, x2, y2, theta2)
 
     assert_allclose(sx, 0, atol=1e-6)
     assert_allclose(sy, 0, atol=1e-6)
@@ -40,7 +31,6 @@ def test_parallel():
     Simple test to check the intersection of lines. Try to intersect positions at (0,0) and (0,1)
     with angles parallel and check the behaviour
     """
-    hill = HillasIntersection()
     x1 = 0
     y1 = 0
     theta1 = 0 * u.deg
@@ -49,29 +39,29 @@ def test_parallel():
     y2 = 0
     theta2 = 0 * u.deg
 
-    sx, sy = hill.intersect_lines(x1, y1, theta1, x2, y2, theta2)
+    sx, sy = HillasIntersection.intersect_lines(x1, y1, theta1, x2, y2, theta2)
     assert_allclose(sx, np.nan, atol=1e-6)
     assert_allclose(sy, np.nan, atol=1e-6)
 
 
-def test_intersection_xmax_reco():
+def test_intersection_xmax_reco(example_subarray):
     """
     Test the reconstruction of xmax with two LSTs that are pointing at zenith = 0.
     The telescopes are places along the x and y axis at the same distance from the center.
     The impact point is hard-coded to be happening in the center of this cartesian system.
     """
-    hill_inter = HillasIntersection()
+    hill_inter = HillasIntersection(subarray=example_subarray)
 
-    horizon_frame = AltAz()
+    altaz = AltAz()
     zen_pointing = 10 * u.deg
 
     array_direction = SkyCoord(
-        alt=90 * u.deg - zen_pointing, az=0 * u.deg, frame=horizon_frame
+        alt=90 * u.deg - zen_pointing, az=0 * u.deg, frame=altaz
     )
     nom_frame = NominalFrame(origin=array_direction)
 
     source_sky_pos_reco = SkyCoord(
-        alt=90 * u.deg - zen_pointing, az=0 * u.deg, frame=horizon_frame
+        alt=90 * u.deg - zen_pointing, az=0 * u.deg, frame=altaz
     )
 
     nom_pos_reco = source_sky_pos_reco.transform_to(nom_frame)
@@ -106,13 +96,13 @@ def test_intersection_xmax_reco():
     print(x_max)
 
 
-def test_intersection_reco_impact_point_tilted():
+def test_intersection_reco_impact_point_tilted(example_subarray):
     """
     Function to test the reconstruction of the impact point in the tilted frame.
     This is done using a squared configuration, of which the impact point occupies a vertex,
     ad the three telescopes the other three vertices.
     """
-    hill_inter = HillasIntersection()
+    hill_inter = HillasIntersection(example_subarray)
 
     delta = 100 * u.m
     tel_x_dict = {1: delta, 2: -delta, 3: -delta}
@@ -132,11 +122,11 @@ def test_intersection_reco_impact_point_tilted():
     np.testing.assert_allclose(reco_konrad[1], -delta.to_value(u.m), atol=1e-8)
 
 
-def test_intersection_weighting_spoiled_parameters():
+def test_intersection_weighting_spoiled_parameters(example_subarray):
     """
     Test that the weighting scheme is useful especially when a telescope is 90 deg with respect to the other two
     """
-    hill_inter = HillasIntersection()
+    hill_inter = HillasIntersection(example_subarray)
 
     delta = 100 * u.m
     tel_x_dict = {1: delta, 2: -delta, 3: -delta}
@@ -157,13 +147,13 @@ def test_intersection_weighting_spoiled_parameters():
     np.testing.assert_allclose(reco_konrad_spoiled[1], -delta.to_value(u.m), atol=1e-1)
 
 
-def test_intersection_nominal_reconstruction():
+def test_intersection_nominal_reconstruction(example_subarray):
     """
     Testing the reconstruction of the position in the nominal frame with a three-telescopes system.
     This is done using a squared configuration, of which the impact point occupies a vertex,
     ad the three telescopes the other three vertices.
     """
-    hill_inter = HillasIntersection()
+    hill_inter = HillasIntersection(example_subarray)
 
     delta = 1.0 * u.m
     horizon_frame = AltAz()
@@ -227,108 +217,16 @@ def test_intersection_nominal_reconstruction():
     )
 
 
-def test_reconstruction():
-    """
-    a test of the complete fit procedure on one event including:
-    • tailcut cleaning
-    • hillas parametrisation
-    • direction fit
-    • position fit
-
-    in the end, proper units in the output are asserted """
-
-    filename = get_dataset_path("gamma_test_large.simtel.gz")
-
-    fit = HillasIntersection()
-
-    source = EventSource(filename, max_events=10)
-    calib = CameraCalibrator(source.subarray)
-
-    horizon_frame = AltAz()
-
-    reconstructed_events = 0
-
-    for event in source:
-        calib(event)
-
-        mc = event.simulation.shower
-        array_pointing = SkyCoord(az=mc.az, alt=mc.alt, frame=horizon_frame)
-
-        hillas_dict = {}
-        telescope_pointings = {}
-        telescope_frame = TelescopeFrame()
-        for tel_id, dl1 in event.dl1.tel.items():
-
-            geom = source.subarray.tel[tel_id].camera.geometry
-            geom_tel_frame = geom.transform_to(telescope_frame)
-
-            telescope_pointings[tel_id] = SkyCoord(
-                alt=event.pointing.tel[tel_id].altitude,
-                az=event.pointing.tel[tel_id].azimuth,
-                frame=horizon_frame,
-            )
-
-            mask = tailcuts_clean(
-                geom, dl1.image, picture_thresh=10.0, boundary_thresh=5.0
-            )
-
-            try:
-                moments = hillas_parameters(geom_tel_frame[mask], dl1.image[mask])
-                hillas_dict[tel_id] = moments
-            except HillasParameterizationError as e:
-                print(e)
-                continue
-
-        if len(hillas_dict) < 2:
-            continue
-        else:
-            reconstructed_events += 1
-
-        # divergent mode put to on even though the file has parallel pointing.
-        fit_result = fit.predict(
-            hillas_dict, source.subarray, array_pointing, telescope_pointings
-        )
-
-        print(fit_result)
-        print(event.simulation.shower.core_x, event.simulation.shower.core_y)
-        fit_result.alt.to(u.deg)
-        fit_result.az.to(u.deg)
-        fit_result.core_x.to(u.m)
-        assert fit_result.is_valid
-
-    assert reconstructed_events > 0
-
-
 def test_reconstruction_works(subarray_and_event_gamma_off_axis_500_gev):
     subarray, event = subarray_and_event_gamma_off_axis_500_gev
-    reconstructor = HillasIntersection()
+    reconstructor = HillasIntersection(subarray)
 
-    array_pointing = SkyCoord(
-        az=event.pointing.array_azimuth,
-        alt=event.pointing.array_altitude,
-        frame=AltAz(),
-    )
-
-    hillas_dict = {
-        tel_id: dl1.parameters.hillas
-        for tel_id, dl1 in event.dl1.tel.items()
-        if dl1.parameters.hillas.width.value > 0
-    }
-
-    telescope_pointings = {
-        tel_id: SkyCoord(alt=pointing.altitude, az=pointing.azimuth, frame=AltAz())
-        for tel_id, pointing in event.pointing.tel.items()
-        if tel_id in hillas_dict
-    }
     true_coord = SkyCoord(
         alt=event.simulation.shower.alt, az=event.simulation.shower.az, frame=AltAz()
     )
 
-    result = reconstructor.predict(
-        hillas_dict, subarray, array_pointing, telescope_pointings
-    )
+    result = reconstructor(event)
     reco_coord = SkyCoord(alt=result.alt, az=result.az, frame=AltAz())
-
     assert reco_coord.separation(true_coord) < 0.1 * u.deg
 
 
@@ -338,26 +236,13 @@ def test_selected_subarray(subarray_and_event_gamma_off_axis_500_gev):
 
     # remove telescopes 2 and 3 to see that HillasIntersection can work
     # with arbirary telescope ids
-    subarray = subarray.select_subarray([1, 4])
+    allowed_tels = {1, 4}
+    for tel_id in subarray.tel.keys():
+        if tel_id not in allowed_tels:
+            event.dl1.tel.pop(tel_id, None)
 
-    reconstructor = HillasIntersection()
-    array_pointing = SkyCoord(
-        az=event.pointing.array_azimuth,
-        alt=event.pointing.array_altitude,
-        frame=AltAz(),
-    )
+    subarray = subarray.select_subarray(allowed_tels)
 
-    # again, only use telescopes 1 and 4
-    hillas_dict = {
-        tel_id: dl1.parameters.hillas
-        for tel_id, dl1 in event.dl1.tel.items()
-        if dl1.parameters.hillas.width.value > 0 and tel_id in {1, 4}
-    }
-
-    telescope_pointings = {
-        tel_id: SkyCoord(alt=pointing.altitude, az=pointing.azimuth, frame=AltAz())
-        for tel_id, pointing in event.pointing.tel.items()
-        if tel_id in hillas_dict
-    }
-
-    reconstructor.predict(hillas_dict, subarray, array_pointing, telescope_pointings)
+    reconstructor = HillasIntersection(subarray)
+    result = reconstructor(event)
+    assert result.is_valid
